import * as React from 'react';
import { Button, Table, Label, Segment, Header, Container } from 'semantic-ui-react';
import { DetailContainer } from './commons/DetailContainer';
import { SensorItems } from './SensorItems';
import Sensor from '@overflow/sensor/api/model/Sensor';
import Probe from '@overflow/probe/api/model/Probe';

export interface SensorDetailsProps {
  sensor?: Sensor;
  probe?: Probe;
}

export interface SensorDetailsState {

}


export class SensorDetails extends React.Component<SensorDetailsProps, SensorDetailsState> {

  constructor(props: any, context: any) {
    super(props, context);
    this.state = {
    };
  }

  public componentWillMount(): void {
    super.componentWillMount();
  }

  public render(): JSX.Element {
    const items = [
      { name: 'Info', child: <Button sensor={this.props.sensor} /> },
      { name: 'Sensor Items', child: <SensorItems sensor={this.props.sensor} /> },
    ];
    const data = { 'probe': this.props.probe };
    return (
      <DetailContainer panes={items} data={data} />
    );
  }
}

export interface SensorBasicInfoProps {
  sensor?: Sensor;
  probe?: Probe;
  onBack?(): void;
}

export interface SensorBasicInfoState {

}

export class SensorBasicInfo extends React.Component<SensorBasicInfoProps, SensorBasicInfoState> {

  constructor(props: any, context: any) {
    super(props, context);
    this.state = {
    };
  }

  public handleStartStop(event: any, data: any): void {
    console.log(event);
  }
  public handleDiscovery(event: any, data: any): void {
    alert('Discovery');
  }

  public handleBack(event: any, data: any): void {
    this.props.onBack();
  }


  public showStartStopBtn(): JSX.Element {
    if (this.props.probe.status.name === 'STARTED') {
      return <Button content='Stop' icon='stop' labelPosition='left' color={'blue'} floated={'right'} onClick={this.handleStartStop} />;
    } else {
      return <Button content='Start' icon='play' labelPosition='left' color={'blue'} floated={'right'} onClick={this.handleStartStop} />;
    }
  }

  public render(): JSX.Element {
    return (
      <Container fluid>
        <Header as='h3' dividing>Sensor Details</Header>
        <Table celled={false}>
          <Table.Body>
            <Table.Row>
              <Table.Cell>
                <Header size='small'>Domain</Header>
              </Table.Cell>
              <Table.Cell>{this.props.probe.domain.name}</Table.Cell>
            </Table.Row>
            <Table.Row>
              <Table.Cell>
                <Header size='small'>Status</Header>
              </Table.Cell>
              <Table.Cell>{this.props.probe.status.name}</Table.Cell>
            </Table.Row>
            <Table.Row>
              <Table.Cell>
                <Header size='small'>Host IP</Header>
              </Table.Cell>
              <Table.Cell>????</Table.Cell>
            </Table.Row>
            <Table.Row>
              <Table.Cell>
                <Header size='small'>Host Name</Header>
              </Table.Cell>
              <Table.Cell>????</Table.Cell>
            </Table.Row>
            <Table.Row>
              <Table.Cell>
                <Header size='small'>Authorized at</Header>
              </Table.Cell>
              <Table.Cell>{this.props.probe.createDate}</Table.Cell>
            </Table.Row>
            <Table.Row>
              <Table.Cell>
                <Header size='small'>Description</Header>
              </Table.Cell>
              <Table.Cell>{this.props.probe.description}</Table.Cell>
            </Table.Row>
          </Table.Body>
        </Table>

        <Button content='Back' icon='left arrow' labelPosition='left' onClick={this.handleBack.bind(this)} />
        <Button content='Discovery' icon='search' labelPosition='left' floated={'right'} positive onClick={this.handleDiscovery} />
        {this.showStartStopBtn()}

      </Container>
    );
  }
}
